@@ -112,7 +112,7 @@ pzgsequ(SuperMatrix *A, double *r, double *c, double *rowcnd,
     m_loc = Astore->m_loc;
     
     /* Get machine constants. */
-    smlnum = dlamch_("S");
+    smlnum = dmach("S");
     bignum = 1. / smlnum;
 
     /* Compute row scale factors. */
