@@ -779,7 +779,7 @@ pzgssvx(superlu_options_t *options, SuperMatrix *A,
 	            }
 
 #if ( PRNTlevel>=2 )
-	            dmin = dlamch_("Overflow");
+	            dmin = dmach("Overflow");
 	            dsum = 0.0;
 	            dprod = 1.0;
 #endif
