@@ -13,6 +13,7 @@
  *     October 15, 2008  latency-reducing panel factorization
  *     July    12, 2011  static scheduling and arbitrary look-ahead
  *     March   13, 2013  change NTAGS to MPI_TAG_UB value
+ *     September 24, 2015 replace xLAMCH by xMACH, using C99 standard.
  *
  * Sketch of the algorithm 
  *
@@ -437,7 +438,7 @@ pzgstrf(superlu_options_t * options, int m, int n, double anorm,
     mycol = MYCOL (iam, grid);
     nsupers = Glu_persist->supno[n - 1] + 1;
     xsup = Glu_persist->xsup;
-    s_eps = slamch_ ("Epsilon");
+    s_eps = smach("Epsilon");
     thresh = s_eps * anorm;
 
     MPI_Attr_get (MPI_COMM_WORLD, MPI_TAG_UB, &attr_val, &flag);
