@@ -82,7 +82,6 @@ pzlaqgs(SuperMatrix *A, double *r, double *c,
     doublecomplex *Aval;
     int_t i, j, irow, jcol, m_loc;
     double large, small;
-    /*extern double dlamch_(char *);*/
     double temp;
 
     /* Quick return if possible */
@@ -96,7 +95,7 @@ pzlaqgs(SuperMatrix *A, double *r, double *c,
     m_loc = Astore->m_loc;
     
     /* Initialize LARGE and SMALL. */
-    small = dlamch_("Safe minimum") / dlamch_("Precision");
+    small = dmach("Safe minimum") / dmach("Precision");
     large = 1. / small;
 
     if (rowcnd >= THRESH && amax >= small && amax <= large) {
