@@ -624,8 +624,8 @@ extern void    countnz_dist (const int_t, int_t *,
 extern long long int fixupL_dist (const int_t, const int_t *, Glu_persist_t *,
 				  Glu_freeable_t *);
 extern int_t   *TreePostorder_dist (int_t, int_t *);
-extern float   slamch_(char *);
-extern double  dlamch_(char *);
+extern float   smach(char *);
+extern double  dmach(char *);
 extern void    *superlu_malloc_dist (size_t);
 extern void    superlu_free_dist (void*);
 extern int_t   *intMalloc_dist (int_t);
